TspRedeemItem class

Constructors

TspRedeemItem({Object? id, String name = '', String? icon, num cost = 0})
const

Properties

cost num
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
final
id Object?
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited