StarPlanetStyleProfile class
Island control style profile — aligns with React Web starPlanetStyleProfiles.
Constructors
- StarPlanetStyleProfile({required String key, bool buttonRaisedShadowEnabled = true, double shadowControlIslandLiftY = 6, double shadowControlPressedY = 2, double pressedDropY = 2, double hoverLiftY = -1, double buttonFaceHeight = 46, String cardIslandShadow = '0 14px 34px rgba(49, 168, 255, 0.20), 0 2px 8px rgba(23, 58, 98, 0.06)'})
-
const
Properties
-
final
-
no setter
-
final
- cardIslandShadow → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hoverLiftY → double
-
final
- key → String
-
final
- pressedDropY → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shadowControlIslandLiftY → double
-
final
- shadowControlPressedY → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
resolve(
String? styleProfile) → StarPlanetStyleProfile
Constants
- islandFlat → const StarPlanetStyleProfile
- islandRaised → const StarPlanetStyleProfile
-
profileKeys
→ const List<
String>